{
    "$graph": [
        {
            "class": "CommandLineTool",
            "label": "samtools view cram to bam",
            "baseCommand": [
                "/opt/samtools/bin/samtools",
                "view",
                "-b"
            ],
            "requirements": [
                {
                    "class": "ResourceRequirement",
                    "ramMin": 4000
                }
            ],
            "arguments": [
                "-o",
                {
                    "valueFrom": "$(runtime.outdir)/output.bam"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 2
                    },
                    "secondaryFiles": [
                        "^.crai"
                    ],
                    "id": "#cram_to_bam.cwl/cram"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "prefix": "-T",
                        "position": 1
                    },
                    "id": "#cram_to_bam.cwl/reference"
                }
            ],
            "id": "#cram_to_bam.cwl",
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "output.bam"
                    },
                    "id": "#cram_to_bam.cwl/bam"
                }
            ]
        },
        {
            "class": "Workflow",
            "label": "cram_to_bam workflow",
            "inputs": [
                {
                    "type": "File",
                    "secondaryFiles": [
                        "^.crai"
                    ],
                    "id": "#workflow.cwl/cram"
                },
                {
                    "type": "string",
                    "id": "#workflow.cwl/reference"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputSource": "#workflow.cwl/index_bam/indexed_bam",
                    "secondaryFiles": [
                        ".bai"
                    ],
                    "id": "#workflow.cwl/bam"
                }
            ],
            "steps": [
                {
                    "run": "#cram_to_bam.cwl",
                    "in": [
                        {
                            "source": "#workflow.cwl/cram",
                            "id": "#workflow.cwl/cram_to_bam/cram"
                        },
                        {
                            "source": "#workflow.cwl/reference",
                            "id": "#workflow.cwl/cram_to_bam/reference"
                        }
                    ],
                    "out": [
                        "#workflow.cwl/cram_to_bam/bam"
                    ],
                    "id": "#workflow.cwl/cram_to_bam"
                },
                {
                    "run": "#index_bam.cwl",
                    "in": [
                        {
                            "source": "#workflow.cwl/cram_to_bam/bam",
                            "id": "#workflow.cwl/index_bam/bam"
                        }
                    ],
                    "out": [
                        "#workflow.cwl/index_bam/indexed_bam"
                    ],
                    "id": "#workflow.cwl/index_bam"
                }
            ],
            "id": "#workflow.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "samtools index",
            "arguments": [
                "cp",
                "$(inputs.bam.path)",
                "$(runtime.outdir)/$(inputs.bam.basename)",
                {
                    "valueFrom": " && ",
                    "shellQuote": false
                },
                "/opt/samtools/bin/samtools",
                "index",
                "$(inputs.bam.path)",
                "$(runtime.outdir)/$(inputs.bam.basename).bai"
            ],
            "requirements": [
                {
                    "class": "ShellCommandRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "id": "#index_bam.cwl/bam"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "secondaryFiles": [
                        ".bai"
                    ],
                    "outputBinding": {
                        "glob": "$(inputs.bam.basename)"
                    },
                    "id": "#index_bam.cwl/indexed_bam"
                }
            ],
            "id": "#index_bam.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "SelectVariants (GATK 3.6)",
            "baseCommand": [
                "/usr/bin/java",
                "-Xmx4g",
                "-jar",
                "/opt/GenomeAnalysisTK.jar",
                "-T",
                "SelectVariants"
            ],
            "requirements": [
                {
                    "class": "ResourceRequirement",
                    "ramMin": 6000,
                    "tmpdirMin": 25000
                }
            ],
            "arguments": [
                "-o",
                {
                    "valueFrom": "$(runtime.outdir)/$(inputs.output_vcf_basename).vcf.gz"
                }
            ],
            "inputs": [
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "prefix": "--excludeFiltered",
                        "position": 4
                    },
                    "id": "#select_variants.cwl/exclude_filtered"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "inputBinding": {
                        "prefix": "-L",
                        "position": 3
                    },
                    "id": "#select_variants.cwl/interval_list"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "default": "select_variants",
                    "id": "#select_variants.cwl/output_vcf_basename"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "prefix": "-R",
                        "position": 1
                    },
                    "id": "#select_variants.cwl/reference"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "--variant",
                        "position": 2
                    },
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#select_variants.cwl/vcf"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "outputBinding": {
                        "glob": "$(inputs.output_vcf_basename).vcf.gz"
                    },
                    "id": "#select_variants.cwl/filtered_vcf"
                }
            ],
            "id": "#select_variants.cwl"
        },
        {
            "class": "Workflow",
            "label": "exome alignment with qc",
            "requirements": [
                {
                    "class": "SubworkflowFeatureRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "id": "#main/bait_intervals"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "id": "#main/bams"
                },
                {
                    "type": [
                        "null",
                        {
                            "type": "array",
                            "items": "string"
                        }
                    ],
                    "id": "#main/bqsr_intervals"
                },
                {
                    "type": "File",
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#main/dbsnp_vcf"
                },
                {
                    "type": "File",
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#main/known_indels"
                },
                {
                    "type": "File",
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#main/mills"
                },
                {
                    "type": "File",
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#main/omni_vcf"
                },
                {
                    "type": "File",
                    "id": "#main/per_base_bait_intervals"
                },
                {
                    "type": "File",
                    "id": "#main/per_base_intervals"
                },
                {
                    "type": "File",
                    "id": "#main/per_target_bait_intervals"
                },
                {
                    "type": "File",
                    "id": "#main/per_target_intervals"
                },
                {
                    "type": "string",
                    "id": "#main/picard_metric_accumulation_level"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "id": "#main/qc_minimum_base_quality"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "id": "#main/qc_minimum_mapping_quality"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "string"
                    },
                    "id": "#main/readgroups"
                },
                {
                    "type": "string",
                    "id": "#main/reference"
                },
                {
                    "type": "File",
                    "id": "#main/target_intervals"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputSource": "#main/qc/alignment_summary_metrics",
                    "id": "#main/alignment_summary_metrics"
                },
                {
                    "type": "File",
                    "outputSource": "#main/alignment/final_cram",
                    "id": "#main/cram"
                },
                {
                    "type": "File",
                    "outputSource": "#main/qc/flagstats",
                    "id": "#main/flagstats"
                },
                {
                    "type": "File",
                    "outputSource": "#main/qc/hs_metrics",
                    "id": "#main/hs_metrics"
                },
                {
                    "type": "File",
                    "outputSource": "#main/qc/insert_size_histogram",
                    "id": "#main/insert_size_histogram"
                },
                {
                    "type": "File",
                    "outputSource": "#main/qc/insert_size_metrics",
                    "id": "#main/insert_size_metrics"
                },
                {
                    "type": "File",
                    "outputSource": "#main/alignment/mark_duplicates_metrics_file",
                    "id": "#main/mark_duplicates_metrics"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputSource": "#main/qc/per_base_coverage_metrics",
                    "id": "#main/per_base_coverage_metrics"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputSource": "#main/qc/per_base_hs_metrics",
                    "id": "#main/per_base_hs_metrics"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputSource": "#main/qc/per_target_coverage_metrics",
                    "id": "#main/per_target_coverage_metrics"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputSource": "#main/qc/per_target_hs_metrics",
                    "id": "#main/per_target_hs_metrics"
                },
                {
                    "type": "File",
                    "outputSource": "#main/qc/verify_bam_id_depth",
                    "id": "#main/verify_bam_id_depth"
                },
                {
                    "type": "File",
                    "outputSource": "#main/qc/verify_bam_id_metrics",
                    "id": "#main/verify_bam_id_metrics"
                }
            ],
            "steps": [
                {
                    "run": "#workflow.cwl_2",
                    "in": [
                        {
                            "source": "#main/bams",
                            "id": "#main/alignment/bams"
                        },
                        {
                            "source": "#main/bqsr_intervals",
                            "id": "#main/alignment/bqsr_intervals"
                        },
                        {
                            "source": "#main/dbsnp_vcf",
                            "id": "#main/alignment/dbsnp_vcf"
                        },
                        {
                            "source": "#main/known_indels",
                            "id": "#main/alignment/known_indels"
                        },
                        {
                            "source": "#main/mills",
                            "id": "#main/alignment/mills"
                        },
                        {
                            "source": "#main/readgroups",
                            "id": "#main/alignment/readgroups"
                        },
                        {
                            "source": "#main/reference",
                            "id": "#main/alignment/reference"
                        }
                    ],
                    "out": [
                        "#main/alignment/final_cram",
                        "#main/alignment/mark_duplicates_metrics_file"
                    ],
                    "id": "#main/alignment"
                },
                {
                    "run": "#workflow_exome.cwl",
                    "in": [
                        {
                            "source": "#main/bait_intervals",
                            "id": "#main/qc/bait_intervals"
                        },
                        {
                            "source": "#main/alignment/final_cram",
                            "id": "#main/qc/cram"
                        },
                        {
                            "source": "#main/qc_minimum_base_quality",
                            "id": "#main/qc/minimum_base_quality"
                        },
                        {
                            "source": "#main/qc_minimum_mapping_quality",
                            "id": "#main/qc/minimum_mapping_quality"
                        },
                        {
                            "source": "#main/omni_vcf",
                            "id": "#main/qc/omni_vcf"
                        },
                        {
                            "source": "#main/per_base_bait_intervals",
                            "id": "#main/qc/per_base_bait_intervals"
                        },
                        {
                            "source": "#main/per_base_intervals",
                            "id": "#main/qc/per_base_intervals"
                        },
                        {
                            "source": "#main/per_target_bait_intervals",
                            "id": "#main/qc/per_target_bait_intervals"
                        },
                        {
                            "source": "#main/per_target_intervals",
                            "id": "#main/qc/per_target_intervals"
                        },
                        {
                            "source": "#main/picard_metric_accumulation_level",
                            "id": "#main/qc/picard_metric_accumulation_level"
                        },
                        {
                            "source": "#main/reference",
                            "id": "#main/qc/reference"
                        },
                        {
                            "source": "#main/target_intervals",
                            "id": "#main/qc/target_intervals"
                        }
                    ],
                    "out": [
                        "#main/qc/insert_size_metrics",
                        "#main/qc/insert_size_histogram",
                        "#main/qc/alignment_summary_metrics",
                        "#main/qc/hs_metrics",
                        "#main/qc/per_target_coverage_metrics",
                        "#main/qc/per_target_hs_metrics",
                        "#main/qc/per_base_coverage_metrics",
                        "#main/qc/per_base_hs_metrics",
                        "#main/qc/flagstats",
                        "#main/qc/verify_bam_id_metrics",
                        "#main/qc/verify_bam_id_depth"
                    ],
                    "id": "#main/qc"
                }
            ],
            "id": "#main"
        },
        {
            "class": "CommandLineTool",
            "label": "collect alignment summary metrics",
            "baseCommand": [
                "/usr/bin/java",
                "-Xmx16g",
                "-jar",
                "/usr/picard/picard.jar",
                "CollectAlignmentSummaryMetrics"
            ],
            "arguments": [
                "OUTPUT=",
                {
                    "valueFrom": "$(runtime.outdir)/AlignmentSummaryMetrics.txt"
                }
            ],
            "requirements": [
                {
                    "class": "ResourceRequirement",
                    "ramMin": 16000
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "INPUT="
                    },
                    "secondaryFiles": [
                        "^.crai"
                    ],
                    "id": "#collect_alignment_summary_metrics.cwl/cram"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "prefix": "METRIC_ACCUMULATION_LEVEL="
                    },
                    "id": "#collect_alignment_summary_metrics.cwl/metric_accumulation_level"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "prefix": "REFERENCE_SEQUENCE="
                    },
                    "id": "#collect_alignment_summary_metrics.cwl/reference"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "AlignmentSummaryMetrics.txt"
                    },
                    "id": "#collect_alignment_summary_metrics.cwl/alignment_summary_metrics"
                }
            ],
            "id": "#collect_alignment_summary_metrics.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "collect HS metrics",
            "baseCommand": [
                "/usr/bin/java",
                "-Xmx16g",
                "-jar",
                "/usr/picard/picard.jar",
                "CollectHsMetrics"
            ],
            "arguments": [
                "O=",
                {
                    "valueFrom": "$(runtime.outdir)/$(inputs.output_prefix)-HsMetrics.txt"
                }
            ],
            "requirements": [
                {
                    "class": "ResourceRequirement",
                    "ramMin": 16000
                },
                {
                    "class": "InlineJavascriptRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "BAIT_INTERVALS="
                    },
                    "id": "#collect_hs_metrics.cwl/bait_intervals"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "I="
                    },
                    "secondaryFiles": [
                        "^.crai"
                    ],
                    "id": "#collect_hs_metrics.cwl/cram"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "prefix": "METRIC_ACCUMULATION_LEVEL="
                    },
                    "id": "#collect_hs_metrics.cwl/metric_accumulation_level"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "default": 1,
                    "inputBinding": {
                        "prefix": "MINIMUM_BASE_QUALITY="
                    },
                    "id": "#collect_hs_metrics.cwl/minimum_base_quality"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "default": 1,
                    "inputBinding": {
                        "prefix": "MINIMUM_MAPPING_QUALITY="
                    },
                    "id": "#collect_hs_metrics.cwl/minimum_mapping_quality"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "default": "out",
                    "id": "#collect_hs_metrics.cwl/output_prefix"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "prefix": "PER_BASE_COVERAGE=",
                        "valueFrom": "${\n    if(self) {\n        return inputs.output_prefix + \"-PerBaseCoverage.txt\"\n    } else {\n        return false;\n    }\n}\n"
                    },
                    "id": "#collect_hs_metrics.cwl/per_base_coverage"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "prefix": "PER_TARGET_COVERAGE=",
                        "valueFrom": "${\n    if(self) {\n        return inputs.output_prefix + \"-PerTargetCoverage.txt\"\n    } else {\n        return false;\n    }\n}\n"
                    },
                    "id": "#collect_hs_metrics.cwl/per_target_coverage"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "prefix": "R="
                    },
                    "id": "#collect_hs_metrics.cwl/reference"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "TARGET_INTERVALS="
                    },
                    "id": "#collect_hs_metrics.cwl/target_intervals"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(input.output_prefix)-HsMetrics.txt"
                    },
                    "id": "#collect_hs_metrics.cwl/hs_metrics"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputBinding": {
                        "glob": "$(input.output_prefix)-PerBaseCoverage.txt"
                    },
                    "id": "#collect_hs_metrics.cwl/per_base_coverage_metrics"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputBinding": {
                        "glob": "$(input.output_prefix)-PerTargetCoverage.txt"
                    },
                    "id": "#collect_hs_metrics.cwl/per_target_coverage_metrics"
                }
            ],
            "id": "#collect_hs_metrics.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "collect insert size metrics",
            "baseCommand": [
                "/usr/bin/java",
                "-Xmx16g",
                "-jar",
                "/usr/picard/picard.jar",
                "CollectInsertSizeMetrics"
            ],
            "arguments": [
                "O=",
                {
                    "valueFrom": "$(runtime.outdir)/InsertSizeMetrics.txt"
                },
                "H=",
                {
                    "valueFrom": "$(runtime.outdir)/InsertSizeHistogram.pdf"
                }
            ],
            "requirements": [
                {
                    "class": "ResourceRequirement",
                    "ramMin": 16000
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "I="
                    },
                    "secondaryFiles": [
                        "^.crai"
                    ],
                    "id": "#collect_insert_size_metrics.cwl/cram"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "prefix": "METRIC_ACCUMULATION_LEVEL="
                    },
                    "id": "#collect_insert_size_metrics.cwl/metric_accumulation_level"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "prefix": "REFERENCE_SEQUENCE="
                    },
                    "id": "#collect_insert_size_metrics.cwl/reference"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "InsertSizeHistogram.pdf"
                    },
                    "id": "#collect_insert_size_metrics.cwl/insert_size_histogram"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "InsertSizeMetrics.txt"
                    },
                    "id": "#collect_insert_size_metrics.cwl/insert_size_metrics"
                }
            ],
            "id": "#collect_insert_size_metrics.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "samtools flagstat",
            "baseCommand": [
                "/opt/samtools/bin/samtools",
                "flagstat"
            ],
            "requirements": [
                {
                    "class": "ResourceRequirement",
                    "ramMin": 4000
                }
            ],
            "stdout": "flagstat.out",
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 1
                    },
                    "secondaryFiles": [
                        "^.crai"
                    ],
                    "id": "#samtools_flagstat.cwl/cram"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "id": "#samtools_flagstat.cwl/flagstats",
                    "outputBinding": {
                        "glob": "flagstat.out"
                    }
                }
            ],
            "id": "#samtools_flagstat.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "verify BAM ID",
            "baseCommand": "/usr/local/bin/verifyBamID",
            "arguments": [
                "--out",
                {
                    "valueFrom": "$(runtime.outdir)/VerifyBamId"
                }
            ],
            "requirements": [
                {
                    "class": "ResourceRequirement",
                    "ramMin": 4000
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "--bam"
                    },
                    "id": "#verify_bam_id.cwl/bam"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "--vcf"
                    },
                    "id": "#verify_bam_id.cwl/vcf"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "VerifyBamId.depthSM"
                    },
                    "id": "#verify_bam_id.cwl/verify_bam_id_depth"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "VerifyBamId.selfSM"
                    },
                    "id": "#verify_bam_id.cwl/verify_bam_id_metrics"
                }
            ],
            "id": "#verify_bam_id.cwl"
        },
        {
            "class": "Workflow",
            "label": "Exome QC workflow",
            "requirements": [
                {
                    "class": "SubworkflowFeatureRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "id": "#workflow_exome.cwl/bait_intervals"
                },
                {
                    "type": "File",
                    "secondaryFiles": [
                        "^.crai"
                    ],
                    "id": "#workflow_exome.cwl/cram"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "id": "#workflow_exome.cwl/minimum_base_quality"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "id": "#workflow_exome.cwl/minimum_mapping_quality"
                },
                {
                    "type": "File",
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#workflow_exome.cwl/omni_vcf"
                },
                {
                    "type": "File",
                    "id": "#workflow_exome.cwl/per_base_bait_intervals"
                },
                {
                    "type": "File",
                    "id": "#workflow_exome.cwl/per_base_intervals"
                },
                {
                    "type": "File",
                    "id": "#workflow_exome.cwl/per_target_bait_intervals"
                },
                {
                    "type": "File",
                    "id": "#workflow_exome.cwl/per_target_intervals"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "default": "ALL_READS",
                    "id": "#workflow_exome.cwl/picard_metric_accumulation_level"
                },
                {
                    "type": "string",
                    "id": "#workflow_exome.cwl/reference"
                },
                {
                    "type": "File",
                    "id": "#workflow_exome.cwl/target_intervals"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputSource": "#workflow_exome.cwl/collect_alignment_summary_metrics/alignment_summary_metrics",
                    "id": "#workflow_exome.cwl/alignment_summary_metrics"
                },
                {
                    "type": "File",
                    "outputSource": "#workflow_exome.cwl/samtools_flagstat/flagstats",
                    "id": "#workflow_exome.cwl/flagstats"
                },
                {
                    "type": "File",
                    "outputSource": "#workflow_exome.cwl/collect_roi_hs_metrics/hs_metrics",
                    "id": "#workflow_exome.cwl/hs_metrics"
                },
                {
                    "type": "File",
                    "outputSource": "#workflow_exome.cwl/collect_insert_size_metrics/insert_size_histogram",
                    "id": "#workflow_exome.cwl/insert_size_histogram"
                },
                {
                    "type": "File",
                    "outputSource": "#workflow_exome.cwl/collect_insert_size_metrics/insert_size_metrics",
                    "id": "#workflow_exome.cwl/insert_size_metrics"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputSource": "#workflow_exome.cwl/collect_per_base_hs_metrics/per_base_coverage_metrics",
                    "id": "#workflow_exome.cwl/per_base_coverage_metrics"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputSource": "#workflow_exome.cwl/collect_per_base_hs_metrics/hs_metrics",
                    "id": "#workflow_exome.cwl/per_base_hs_metrics"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputSource": "#workflow_exome.cwl/collect_per_target_hs_metrics/per_target_coverage_metrics",
                    "id": "#workflow_exome.cwl/per_target_coverage_metrics"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputSource": "#workflow_exome.cwl/collect_per_target_hs_metrics/hs_metrics",
                    "id": "#workflow_exome.cwl/per_target_hs_metrics"
                },
                {
                    "type": "File",
                    "outputSource": "#workflow_exome.cwl/verify_bam_id/verify_bam_id_depth",
                    "id": "#workflow_exome.cwl/verify_bam_id_depth"
                },
                {
                    "type": "File",
                    "outputSource": "#workflow_exome.cwl/verify_bam_id/verify_bam_id_metrics",
                    "id": "#workflow_exome.cwl/verify_bam_id_metrics"
                }
            ],
            "steps": [
                {
                    "run": "#collect_alignment_summary_metrics.cwl",
                    "in": [
                        {
                            "source": "#workflow_exome.cwl/cram",
                            "id": "#workflow_exome.cwl/collect_alignment_summary_metrics/cram"
                        },
                        {
                            "source": "#workflow_exome.cwl/picard_metric_accumulation_level",
                            "id": "#workflow_exome.cwl/collect_alignment_summary_metrics/metric_accumulation_level"
                        },
                        {
                            "source": "#workflow_exome.cwl/reference",
                            "id": "#workflow_exome.cwl/collect_alignment_summary_metrics/reference"
                        }
                    ],
                    "out": [
                        "#workflow_exome.cwl/collect_alignment_summary_metrics/alignment_summary_metrics"
                    ],
                    "id": "#workflow_exome.cwl/collect_alignment_summary_metrics"
                },
                {
                    "run": "#collect_insert_size_metrics.cwl",
                    "in": [
                        {
                            "source": "#workflow_exome.cwl/cram",
                            "id": "#workflow_exome.cwl/collect_insert_size_metrics/cram"
                        },
                        {
                            "source": "#workflow_exome.cwl/picard_metric_accumulation_level",
                            "id": "#workflow_exome.cwl/collect_insert_size_metrics/metric_accumulation_level"
                        },
                        {
                            "source": "#workflow_exome.cwl/reference",
                            "id": "#workflow_exome.cwl/collect_insert_size_metrics/reference"
                        }
                    ],
                    "out": [
                        "#workflow_exome.cwl/collect_insert_size_metrics/insert_size_metrics",
                        "#workflow_exome.cwl/collect_insert_size_metrics/insert_size_histogram"
                    ],
                    "id": "#workflow_exome.cwl/collect_insert_size_metrics"
                },
                {
                    "run": "#collect_hs_metrics.cwl",
                    "in": [
                        {
                            "source": "#workflow_exome.cwl/per_base_bait_intervals",
                            "id": "#workflow_exome.cwl/collect_per_base_hs_metrics/bait_intervals"
                        },
                        {
                            "source": "#workflow_exome.cwl/cram",
                            "id": "#workflow_exome.cwl/collect_per_base_hs_metrics/cram"
                        },
                        {
                            "valueFrom": "ALL_READS",
                            "id": "#workflow_exome.cwl/collect_per_base_hs_metrics/metric_accumulation_level"
                        },
                        {
                            "source": "#workflow_exome.cwl/minimum_base_quality",
                            "id": "#workflow_exome.cwl/collect_per_base_hs_metrics/minimum_base_quality"
                        },
                        {
                            "source": "#workflow_exome.cwl/minimum_mapping_quality",
                            "id": "#workflow_exome.cwl/collect_per_base_hs_metrics/minimum_mapping_quality"
                        },
                        {
                            "valueFrom": "base",
                            "id": "#workflow_exome.cwl/collect_per_base_hs_metrics/output_prefix"
                        },
                        {
                            "default": true,
                            "id": "#workflow_exome.cwl/collect_per_base_hs_metrics/per_base_coverage"
                        },
                        {
                            "default": false,
                            "id": "#workflow_exome.cwl/collect_per_base_hs_metrics/per_target_coverage"
                        },
                        {
                            "source": "#workflow_exome.cwl/reference",
                            "id": "#workflow_exome.cwl/collect_per_base_hs_metrics/reference"
                        },
                        {
                            "source": "#workflow_exome.cwl/per_base_intervals",
                            "id": "#workflow_exome.cwl/collect_per_base_hs_metrics/target_intervals"
                        }
                    ],
                    "out": [
                        "#workflow_exome.cwl/collect_per_base_hs_metrics/hs_metrics",
                        "#workflow_exome.cwl/collect_per_base_hs_metrics/per_base_coverage_metrics"
                    ],
                    "id": "#workflow_exome.cwl/collect_per_base_hs_metrics"
                },
                {
                    "run": "#collect_hs_metrics.cwl",
                    "in": [
                        {
                            "source": "#workflow_exome.cwl/per_target_bait_intervals",
                            "id": "#workflow_exome.cwl/collect_per_target_hs_metrics/bait_intervals"
                        },
                        {
                            "source": "#workflow_exome.cwl/cram",
                            "id": "#workflow_exome.cwl/collect_per_target_hs_metrics/cram"
                        },
                        {
                            "valueFrom": "ALL_READS",
                            "id": "#workflow_exome.cwl/collect_per_target_hs_metrics/metric_accumulation_level"
                        },
                        {
                            "source": "#workflow_exome.cwl/minimum_base_quality",
                            "id": "#workflow_exome.cwl/collect_per_target_hs_metrics/minimum_base_quality"
                        },
                        {
                            "source": "#workflow_exome.cwl/minimum_mapping_quality",
                            "id": "#workflow_exome.cwl/collect_per_target_hs_metrics/minimum_mapping_quality"
                        },
                        {
                            "valueFrom": "target",
                            "id": "#workflow_exome.cwl/collect_per_target_hs_metrics/output_prefix"
                        },
                        {
                            "default": false,
                            "id": "#workflow_exome.cwl/collect_per_target_hs_metrics/per_base_coverage"
                        },
                        {
                            "default": true,
                            "id": "#workflow_exome.cwl/collect_per_target_hs_metrics/per_target_coverage"
                        },
                        {
                            "source": "#workflow_exome.cwl/reference",
                            "id": "#workflow_exome.cwl/collect_per_target_hs_metrics/reference"
                        },
                        {
                            "source": "#workflow_exome.cwl/per_target_intervals",
                            "id": "#workflow_exome.cwl/collect_per_target_hs_metrics/target_intervals"
                        }
                    ],
                    "out": [
                        "#workflow_exome.cwl/collect_per_target_hs_metrics/hs_metrics",
                        "#workflow_exome.cwl/collect_per_target_hs_metrics/per_target_coverage_metrics"
                    ],
                    "id": "#workflow_exome.cwl/collect_per_target_hs_metrics"
                },
                {
                    "run": "#collect_hs_metrics.cwl",
                    "in": [
                        {
                            "source": "#workflow_exome.cwl/bait_intervals",
                            "id": "#workflow_exome.cwl/collect_roi_hs_metrics/bait_intervals"
                        },
                        {
                            "source": "#workflow_exome.cwl/cram",
                            "id": "#workflow_exome.cwl/collect_roi_hs_metrics/cram"
                        },
                        {
                            "valueFrom": "ALL_READS",
                            "id": "#workflow_exome.cwl/collect_roi_hs_metrics/metric_accumulation_level"
                        },
                        {
                            "source": "#workflow_exome.cwl/minimum_base_quality",
                            "id": "#workflow_exome.cwl/collect_roi_hs_metrics/minimum_base_quality"
                        },
                        {
                            "source": "#workflow_exome.cwl/minimum_mapping_quality",
                            "id": "#workflow_exome.cwl/collect_roi_hs_metrics/minimum_mapping_quality"
                        },
                        {
                            "valueFrom": "roi",
                            "id": "#workflow_exome.cwl/collect_roi_hs_metrics/output_prefix"
                        },
                        {
                            "default": false,
                            "id": "#workflow_exome.cwl/collect_roi_hs_metrics/per_base_coverage"
                        },
                        {
                            "default": false,
                            "id": "#workflow_exome.cwl/collect_roi_hs_metrics/per_target_coverage"
                        },
                        {
                            "source": "#workflow_exome.cwl/reference",
                            "id": "#workflow_exome.cwl/collect_roi_hs_metrics/reference"
                        },
                        {
                            "source": "#workflow_exome.cwl/target_intervals",
                            "id": "#workflow_exome.cwl/collect_roi_hs_metrics/target_intervals"
                        }
                    ],
                    "out": [
                        "#workflow_exome.cwl/collect_roi_hs_metrics/hs_metrics"
                    ],
                    "id": "#workflow_exome.cwl/collect_roi_hs_metrics"
                },
                {
                    "run": "#workflow.cwl",
                    "in": [
                        {
                            "source": "#workflow_exome.cwl/cram",
                            "id": "#workflow_exome.cwl/cram_to_bam/cram"
                        },
                        {
                            "source": "#workflow_exome.cwl/reference",
                            "id": "#workflow_exome.cwl/cram_to_bam/reference"
                        }
                    ],
                    "out": [
                        "#workflow_exome.cwl/cram_to_bam/bam"
                    ],
                    "id": "#workflow_exome.cwl/cram_to_bam"
                },
                {
                    "run": "#samtools_flagstat.cwl",
                    "in": [
                        {
                            "source": "#workflow_exome.cwl/cram",
                            "id": "#workflow_exome.cwl/samtools_flagstat/cram"
                        }
                    ],
                    "out": [
                        "#workflow_exome.cwl/samtools_flagstat/flagstats"
                    ],
                    "id": "#workflow_exome.cwl/samtools_flagstat"
                },
                {
                    "run": "#select_variants.cwl",
                    "in": [
                        {
                            "source": "#workflow_exome.cwl/target_intervals",
                            "id": "#workflow_exome.cwl/select_variants/interval_list"
                        },
                        {
                            "source": "#workflow_exome.cwl/reference",
                            "id": "#workflow_exome.cwl/select_variants/reference"
                        },
                        {
                            "source": "#workflow_exome.cwl/omni_vcf",
                            "id": "#workflow_exome.cwl/select_variants/vcf"
                        }
                    ],
                    "out": [
                        "#workflow_exome.cwl/select_variants/filtered_vcf"
                    ],
                    "id": "#workflow_exome.cwl/select_variants"
                },
                {
                    "run": "#verify_bam_id.cwl",
                    "in": [
                        {
                            "source": "#workflow_exome.cwl/cram_to_bam/bam",
                            "id": "#workflow_exome.cwl/verify_bam_id/bam"
                        },
                        {
                            "source": "#workflow_exome.cwl/select_variants/filtered_vcf",
                            "id": "#workflow_exome.cwl/verify_bam_id/vcf"
                        }
                    ],
                    "out": [
                        "#workflow_exome.cwl/verify_bam_id/verify_bam_id_metrics",
                        "#workflow_exome.cwl/verify_bam_id/verify_bam_id_depth"
                    ],
                    "id": "#workflow_exome.cwl/verify_bam_id"
                }
            ],
            "id": "#workflow_exome.cwl"
        },
        {
            "class": "Workflow",
            "label": "Unaligned to aligned BAM",
            "requirements": [
                {
                    "class": "ScatterFeatureRequirement"
                },
                {
                    "class": "SubworkflowFeatureRequirement"
                },
                {
                    "class": "MultipleInputFeatureRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "id": "#align.cwl/bam"
                },
                {
                    "type": "string",
                    "id": "#align.cwl/readgroup"
                },
                {
                    "type": "string",
                    "id": "#align.cwl/reference"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputSource": "#align.cwl/align_and_tag/aligned_bam",
                    "id": "#align.cwl/tagged_bam"
                }
            ],
            "steps": [
                {
                    "run": "#align_and_tag.cwl",
                    "in": [
                        {
                            "source": "#align.cwl/bam",
                            "id": "#align.cwl/align_and_tag/bam"
                        },
                        {
                            "source": "#align.cwl/readgroup",
                            "id": "#align.cwl/align_and_tag/readgroup"
                        },
                        {
                            "source": "#align.cwl/reference",
                            "id": "#align.cwl/align_and_tag/reference"
                        }
                    ],
                    "out": [
                        "#align.cwl/align_and_tag/aligned_bam"
                    ],
                    "id": "#align.cwl/align_and_tag"
                }
            ],
            "id": "#align.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "align with bwa_mem and tag",
            "baseCommand": [
                "/bin/bash",
                "/usr/bin/alignment_helper.sh"
            ],
            "requirements": [
                {
                    "class": "ResourceRequirement",
                    "coresMin": 8,
                    "ramMin": 20000
                }
            ],
            "stdout": "refAlign.bam",
            "arguments": [
                {
                    "position": 4,
                    "valueFrom": "$(runtime.cores)"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 1
                    },
                    "id": "#align_and_tag.cwl/bam"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "position": 2
                    },
                    "id": "#align_and_tag.cwl/readgroup"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "position": 3
                    },
                    "id": "#align_and_tag.cwl/reference"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "id": "#align_and_tag.cwl/aligned_bam",
                    "outputBinding": {
                        "glob": "refAlign.bam"
                    }
                }
            ],
            "id": "#align_and_tag.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "apply BQSR",
            "baseCommand": [
                "/usr/bin/java",
                "-Xmx16g",
                "-jar",
                "/opt/GenomeAnalysisTK.jar",
                "-T",
                "PrintReads"
            ],
            "arguments": [
                "-o",
                {
                    "valueFrom": "$(runtime.outdir)/Final.bam"
                },
                "-preserveQ",
                "6",
                "-SQQ",
                "10",
                "-SQQ",
                "20",
                "-SQQ",
                "30",
                "-nct",
                "8",
                "--disable_indel_quals"
            ],
            "requirements": [
                {
                    "class": "ResourceRequirement",
                    "ramMin": 18000
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "-I",
                        "position": 2
                    },
                    "secondaryFiles": [
                        ".bai"
                    ],
                    "id": "#apply_bqsr.cwl/bam"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "-BQSR",
                        "position": 3
                    },
                    "id": "#apply_bqsr.cwl/bqsr_table"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "prefix": "-R",
                        "position": 1
                    },
                    "id": "#apply_bqsr.cwl/reference"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "Final.bam"
                    },
                    "secondaryFiles": [
                        "^.bai"
                    ],
                    "id": "#apply_bqsr.cwl/bqsr_bam"
                }
            ],
            "id": "#apply_bqsr.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "BAM to CRAM conversion",
            "baseCommand": [
                "/opt/samtools/bin/samtools",
                "view",
                "-C"
            ],
            "stdout": "final.cram",
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 2
                    },
                    "id": "#bam_to_cram.cwl/bam"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "prefix": "-T",
                        "position": 1
                    },
                    "id": "#bam_to_cram.cwl/reference"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "id": "#bam_to_cram.cwl/cram",
                    "outputBinding": {
                        "glob": "final.cram"
                    }
                }
            ],
            "id": "#bam_to_cram.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "create BQSR table",
            "baseCommand": [
                "/usr/bin/java",
                "-Xmx16g",
                "-jar",
                "/opt/GenomeAnalysisTK.jar",
                "-T",
                "BaseRecalibrator"
            ],
            "arguments": [
                "-o",
                {
                    "valueFrom": "$(runtime.outdir)/bqsr.table"
                },
                "--preserve_qscores_less_than",
                "6",
                "--disable_auto_index_creation_and_locking_when_reading_rods",
                "--disable_bam_indexing",
                "-dfrac",
                ".1",
                "-nct",
                "4"
            ],
            "requirements": [
                {
                    "class": "ResourceRequirement",
                    "ramMin": 16000
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "-I",
                        "position": 3
                    },
                    "secondaryFiles": [
                        ".bai"
                    ],
                    "id": "#bqsr.cwl/bam"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "string",
                        "inputBinding": {
                            "prefix": "-L"
                        }
                    },
                    "inputBinding": {
                        "position": 1
                    },
                    "default": [
                        "chr1",
                        "chr2",
                        "chr3",
                        "chr4",
                        "chr5",
                        "chr6",
                        "chr7",
                        "chr8",
                        "chr9",
                        "chr10",
                        "chr11",
                        "chr12",
                        "chr13",
                        "chr14",
                        "chr15",
                        "chr16",
                        "chr17",
                        "chr18",
                        "chr19",
                        "chr20",
                        "chr21",
                        "chr22"
                    ],
                    "id": "#bqsr.cwl/intervals"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "File",
                        "inputBinding": {
                            "prefix": "-knownSites",
                            "position": 4
                        }
                    },
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#bqsr.cwl/known_sites"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "prefix": "-R",
                        "position": 2
                    },
                    "id": "#bqsr.cwl/reference"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "bqsr.table"
                    },
                    "id": "#bqsr.cwl/bqsr_table"
                }
            ],
            "id": "#bqsr.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "samtools index cram",
            "arguments": [
                "cp",
                "$(inputs.cram.path)",
                "$(runtime.outdir)/$(inputs.cram.basename)",
                {
                    "valueFrom": " && ",
                    "shellQuote": false
                },
                "/opt/samtools/bin/samtools",
                "index",
                "$(runtime.outdir)/$(inputs.cram.basename)",
                "$(runtime.outdir)/$(inputs.cram.basename).crai",
                {
                    "valueFrom": " && ",
                    "shellQuote": false
                },
                "ln",
                "-s",
                "$(inputs.cram.basename).crai",
                "$(runtime.outdir)/$(inputs.cram.nameroot).crai"
            ],
            "requirements": [
                {
                    "class": "ShellCommandRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "id": "#index_cram.cwl/cram"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "secondaryFiles": [
                        ".crai",
                        "^.crai"
                    ],
                    "outputBinding": {
                        "glob": "$(inputs.cram.basename)"
                    },
                    "id": "#index_cram.cwl/indexed_cram"
                }
            ],
            "id": "#index_cram.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "mark duplicates and sort",
            "baseCommand": [
                "/bin/bash",
                "/usr/bin/markduplicates_helper.sh"
            ],
            "requirements": [
                {
                    "class": "ResourceRequirement",
                    "coresMin": 8,
                    "ramMin": 40000
                }
            ],
            "arguments": [
                {
                    "position": 2,
                    "valueFrom": "$(runtime.cores)"
                },
                {
                    "position": 3,
                    "valueFrom": "$(runtime.outdir)/MarkedSorted.bam"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 1
                    },
                    "id": "#mark_duplicates_and_sort.cwl/bam"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "mark_dups_metrics.txt"
                    },
                    "id": "#mark_duplicates_and_sort.cwl/metrics_file"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "MarkedSorted.bam"
                    },
                    "secondaryFiles": [
                        ".bai"
                    ],
                    "id": "#mark_duplicates_and_sort.cwl/sorted_bam"
                }
            ],
            "id": "#mark_duplicates_and_sort.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "merge BAMs",
            "baseCommand": [
                "/opt/samtools/bin/samtools",
                "merge"
            ],
            "arguments": [
                "AlignedMerged.bam"
            ],
            "inputs": [
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "inputBinding": {
                        "position": 1
                    },
                    "id": "#merge.cwl/bams"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "AlignedMerged.bam"
                    },
                    "id": "#merge.cwl/merged_bam"
                }
            ],
            "id": "#merge.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "sort BAM by name",
            "baseCommand": [
                "/usr/bin/sambamba",
                "sort"
            ],
            "arguments": [
                "-t",
                {
                    "valueFrom": "$(runtime.cores)"
                },
                "-m",
                "12G",
                "-n",
                "-o",
                {
                    "valueFrom": "$(runtime.outdir)/NameSorted.bam"
                }
            ],
            "requirements": [
                {
                    "class": "ResourceRequirement",
                    "ramMin": 13000,
                    "coresMin": 8
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 1
                    },
                    "id": "#name_sort.cwl/bam"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "NameSorted.bam"
                    },
                    "id": "#name_sort.cwl/name_sorted_bam"
                }
            ],
            "id": "#name_sort.cwl"
        },
        {
            "class": "Workflow",
            "label": "Unaligned BAM to BQSR and VCF",
            "requirements": [
                {
                    "class": "ScatterFeatureRequirement"
                },
                {
                    "class": "SubworkflowFeatureRequirement"
                },
                {
                    "class": "MultipleInputFeatureRequirement"
                }
            ],
            "inputs": [
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "id": "#workflow.cwl_2/bams"
                },
                {
                    "type": [
                        "null",
                        {
                            "type": "array",
                            "items": "string"
                        }
                    ],
                    "id": "#workflow.cwl_2/bqsr_intervals"
                },
                {
                    "type": "File",
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#workflow.cwl_2/dbsnp_vcf"
                },
                {
                    "type": "File",
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#workflow.cwl_2/known_indels"
                },
                {
                    "type": "File",
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#workflow.cwl_2/mills"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "string"
                    },
                    "id": "#workflow.cwl_2/readgroups"
                },
                {
                    "type": "string",
                    "id": "#workflow.cwl_2/reference"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputSource": "#workflow.cwl_2/index_cram/indexed_cram",
                    "secondaryFiles": [
                        ".crai",
                        "^.crai"
                    ],
                    "id": "#workflow.cwl_2/final_cram"
                },
                {
                    "type": "File",
                    "outputSource": "#workflow.cwl_2/mark_duplicates_and_sort/metrics_file",
                    "id": "#workflow.cwl_2/mark_duplicates_metrics_file"
                }
            ],
            "steps": [
                {
                    "scatter": [
                        "#workflow.cwl_2/align/bam",
                        "#workflow.cwl_2/align/readgroup"
                    ],
                    "scatterMethod": "dotproduct",
                    "run": "#align.cwl",
                    "in": [
                        {
                            "source": "#workflow.cwl_2/bams",
                            "id": "#workflow.cwl_2/align/bam"
                        },
                        {
                            "source": "#workflow.cwl_2/readgroups",
                            "id": "#workflow.cwl_2/align/readgroup"
                        },
                        {
                            "source": "#workflow.cwl_2/reference",
                            "id": "#workflow.cwl_2/align/reference"
                        }
                    ],
                    "out": [
                        "#workflow.cwl_2/align/tagged_bam"
                    ],
                    "id": "#workflow.cwl_2/align"
                },
                {
                    "run": "#apply_bqsr.cwl",
                    "in": [
                        {
                            "source": "#workflow.cwl_2/mark_duplicates_and_sort/sorted_bam",
                            "id": "#workflow.cwl_2/apply_bqsr/bam"
                        },
                        {
                            "source": "#workflow.cwl_2/bqsr/bqsr_table",
                            "id": "#workflow.cwl_2/apply_bqsr/bqsr_table"
                        },
                        {
                            "source": "#workflow.cwl_2/reference",
                            "id": "#workflow.cwl_2/apply_bqsr/reference"
                        }
                    ],
                    "out": [
                        "#workflow.cwl_2/apply_bqsr/bqsr_bam"
                    ],
                    "id": "#workflow.cwl_2/apply_bqsr"
                },
                {
                    "run": "#bam_to_cram.cwl",
                    "in": [
                        {
                            "source": "#workflow.cwl_2/apply_bqsr/bqsr_bam",
                            "id": "#workflow.cwl_2/bam_to_cram/bam"
                        },
                        {
                            "source": "#workflow.cwl_2/reference",
                            "id": "#workflow.cwl_2/bam_to_cram/reference"
                        }
                    ],
                    "out": [
                        "#workflow.cwl_2/bam_to_cram/cram"
                    ],
                    "id": "#workflow.cwl_2/bam_to_cram"
                },
                {
                    "run": "#bqsr.cwl",
                    "in": [
                        {
                            "source": "#workflow.cwl_2/mark_duplicates_and_sort/sorted_bam",
                            "id": "#workflow.cwl_2/bqsr/bam"
                        },
                        {
                            "source": "#workflow.cwl_2/bqsr_intervals",
                            "id": "#workflow.cwl_2/bqsr/intervals"
                        },
                        {
                            "source": [
                                "#workflow.cwl_2/dbsnp_vcf",
                                "#workflow.cwl_2/mills",
                                "#workflow.cwl_2/known_indels"
                            ],
                            "id": "#workflow.cwl_2/bqsr/known_sites"
                        },
                        {
                            "source": "#workflow.cwl_2/reference",
                            "id": "#workflow.cwl_2/bqsr/reference"
                        }
                    ],
                    "out": [
                        "#workflow.cwl_2/bqsr/bqsr_table"
                    ],
                    "id": "#workflow.cwl_2/bqsr"
                },
                {
                    "run": "#index_cram.cwl",
                    "in": [
                        {
                            "source": "#workflow.cwl_2/bam_to_cram/cram",
                            "id": "#workflow.cwl_2/index_cram/cram"
                        }
                    ],
                    "out": [
                        "#workflow.cwl_2/index_cram/indexed_cram"
                    ],
                    "id": "#workflow.cwl_2/index_cram"
                },
                {
                    "run": "#mark_duplicates_and_sort.cwl",
                    "in": [
                        {
                            "source": "#workflow.cwl_2/name_sort/name_sorted_bam",
                            "id": "#workflow.cwl_2/mark_duplicates_and_sort/bam"
                        }
                    ],
                    "out": [
                        "#workflow.cwl_2/mark_duplicates_and_sort/sorted_bam",
                        "#workflow.cwl_2/mark_duplicates_and_sort/metrics_file"
                    ],
                    "id": "#workflow.cwl_2/mark_duplicates_and_sort"
                },
                {
                    "run": "#merge.cwl",
                    "in": [
                        {
                            "source": "#workflow.cwl_2/align/tagged_bam",
                            "id": "#workflow.cwl_2/merge/bams"
                        }
                    ],
                    "out": [
                        "#workflow.cwl_2/merge/merged_bam"
                    ],
                    "id": "#workflow.cwl_2/merge"
                },
                {
                    "run": "#name_sort.cwl",
                    "in": [
                        {
                            "source": "#workflow.cwl_2/merge/merged_bam",
                            "id": "#workflow.cwl_2/name_sort/bam"
                        }
                    ],
                    "out": [
                        "#workflow.cwl_2/name_sort/name_sorted_bam"
                    ],
                    "id": "#workflow.cwl_2/name_sort"
                }
            ],
            "id": "#workflow.cwl_2"
        }
    ],
    "cwlVersion": "v1.0"
}
